==> pbt_core-0.3.5-py3-none-any.whl: core/app.py <==
from enum import Enum
from typing import Any, Sequence, Optional

from fastapi import APIRouter, FastAPI, Request
from pydantic import BaseSettings, Field
from sentry_sdk import init as sentry_init

from . import fn

# noinspection PyUnresolvedReferences
from .logging import log


class Environment(Enum):
    """Environment - for sentry commonly."""

    develop = 'develop'
    production = 'production'


class Config(BaseSettings):
    """Config."""

    secret: str

    service_name: str = 'Service'
    service_info: str = 'Service information'

    api_host: str = '127.0.0.1'
    api_port: int = 8080

    environment: Environment = Field(default=Environment.develop)
    debug: bool = Field(default_factory=fn.is_debug)
    testing: bool = Field(default_factory=fn.is_testing)

    routers: Sequence[APIRouter] = Field(default_factory=list)
    middleware: Sequence[Any] = Field(default_factory=list)

    sentry_dsn: Optional[str]

    @staticmethod
    def create(
        routers: Sequence[APIRouter] = None,
        middleware: Sequence[Any] = None,
        **kwargs,
    ):
        """Create from env with runtime."""
        return Config(
            routers=routers if routers else [],
            middleware=middleware if middleware else [],
        )

    class Config:

        case_sensitive = False
        env_file = '.env'
        validate_all = True


index = APIRouter(prefix='', tags=['Maintenance'])


@index.get('/status', status_code=200)
async def status(request: Request):
    """Maintenance service status."""
    return {'status': 'ready'}


def create_from_config(conf: Config, skip_index: bool = False) -> FastAPI:
    """Create api from config."""
    api = FastAPI(docs_url='/docs')

    if conf.sentry_dsn:
        sentry_init(dsn=conf.sentry_dsn, environment=conf.environment)

    api.title = conf.service_name
    api.description = conf.service_info

    for middleware in conf.middleware:
        api.add_middleware(middleware)

    if not skip_index:
        api.include_router(index)

    for router in conf.routers:
        api.include_router(router)

    return api


__all__ = 'Config', 'create_from_config', 'log'

==> pbt_core-1.1.1-py3-none-any.whl: core/app.py <==
from enum import Enum
from typing import Any, Sequence, Optional

from fastapi import APIRouter, FastAPI, Request
from pydantic import BaseSettings, Field
from sentry_sdk import init as sentry_init

from . import fn

from .middleware import ServiceMiddleware
from .logging import log


class Environment(Enum):
    """Environment - for sentry commonly."""

    develop = 'develop'
    production = 'production'


class Config(BaseSettings):
    """Config."""

    secret: str

    service_name: str = 'Service'
    service_info: str = 'Service information'

    api_host: str = '127.0.0.1'
    api_port: int = 8080

    environment: Environment = Field(default=Environment.develop)
    debug: bool = Field(default_factory=fn.is_debug)
    testing: bool = Field(default_factory=fn.is_testing)

    routers: Sequence[APIRouter] = Field(default_factory=list)
    middleware: Sequence[Any] = Field(default_factory=list)

    sentry_dsn: Optional[str]

    @staticmethod
    def create(
        routers: Sequence[APIRouter] = None,
        middleware: Sequence[Any] = None,
        **kwargs,
    ):
        """Create from env with runtime."""
        return Config(
            routers=routers if routers else [],
            middleware=middleware if middleware else [],
        )

    class Config:

        case_sensitive = False
        env_file = '.env'
        validate_all = True


index = APIRouter(prefix='', tags=['Maintenance'])


@index.get('/status', status_code=200)
async def status(request: Request):
    """Maintenance service status."""
    return {'status': 'ready'}


def create_from_config(
    conf: Config,
    skip_index: bool = False,
    **kwargs,
) -> FastAPI:
    """Create api from config."""
    api = FastAPI(docs_url='/docs')
    api.title = conf.service_name
    api.description = conf.service_info

    if not conf.testing:
        api.add_middleware(ServiceMiddleware)
        if conf.sentry_dsn:
            sentry_init(dsn=conf.sentry_dsn, environment=conf.environment)

    for middleware in conf.middleware:
        api.add_middleware(middleware)

    if not skip_index:
        api.include_router(index)

    for router in conf.routers:
        api.include_router(router)

    return api


__all__ = 'Config', 'create_from_config', 'log'
